@@ -43,7 +43,11 @@ class Tar(Archiver):
         self.type=None
         
     
-    def load(self, job, log, now):
+    def load(self, job, manager):
+
+        log=manager.log
+        now=manager.now
+
         errors, warnings, extra={}, {}, ''
 
         #
@@ -169,7 +173,10 @@ class Tar(Archiver):
         
         return errors, warnings, extra
     
-    def run(self, command, job, log, now):
+    def run(self, command, job, manager):
+
+        log=manager.log
+        now=manager.now
 
         target_dir=os.path.dirname(self.target)
         target_noext=self.target
@@ -271,10 +278,6 @@ class Tar(Archiver):
         status+='cmd_tar=%s\r\n' % ' '.join(self.tar_args)
         status+='cmd_find=%s\r\n' % ' '.join(self.find_args)
 
-        for line in status.split('\r\n'):
-            if line:
-                log.info('    %s', line)
-        
         #
         # dir of target directory
         #
@@ -283,21 +286,21 @@ class Tar(Archiver):
         attachements=[ # the type, subtype and coding is not used
                        ('err.txt', self.error, None, 'text', 'plain', 'utf-8'),
                        ('dir.txt', None, target_dir_list.encode('utf-8'), 'text', 'plain', 'utf-8'),
-                       ('config.ini', job['config'], None, 'text', 'plain', job['config_encoding']),
-                       ('status.txt', None, status.encode('utf-8'), 'text', 'plain', 'utf-8'),
                     ]
 #        if std_out:
 #            attachements.append(('stdout.txt', None, std_out, 'text', 'plain', 'cp850'))
 #        if std_err:
 #            attachements.append(('stderr.txt', None, std_err, 'text', 'plain', 'cp850'))
         
-        msg_body=job['msg_header']+'\n'+status
-        subject='MKBACKUP BACKUP %s %s' % (backup_status, job['name'])
-        if job['mail']:
-            sendmail(job['sender'], job['recipients'], subject, msg_body, attachements, job['smtp_host'], job['smtp_port'])
-
-        if backup_status=='OK':
-            return 0
-        else:
-            return 1
+#        msg_body=job['msg_header']+'\n'+status
+#        subject='MKBACKUP BACKUP %s %s' % (backup_status, job['name'])
+#        if job['mail']:
+#            sendmail(job['sender'], job['recipients'], subject, msg_body, attachements, job['smtp_host'], job['smtp_port'])
+#
+#        if backup_status=='OK':
+#            return 0
+#        else:
+#            return 1
+        
+        return backup_status, status, attachements
 
